import psspyObject
import os


def run_case(dsr_percentage, dsr_time_delay):
    # Outage in Norway with low system inertia, and with UFLS, HVDC Emergency Power and DSR activation

# CONFIGURE PSSPY VARIABLES AND MODELS
    north_sea_link_load = -1400  # North Sea Link 1400 MW, minus sign means import
    nord_link_load = -1400  # NordLink 1400 MW
    current_case = psspyObject.PsspyCase("case1_outage_norway_with_ufls_hvdc_dsr")
    # current_case = psspyObject.PsspyCase("case1_dsr_high_time_delay")
    current_case.configure_case_options(False, 90.0, 0, 10, True, False, True, True, True)

# STATIC LOAD FLOW ADJUSTMENTS
    current_case.add_ufls()
    current_case.add_hvdc_buses()
    current_case.set_hvdc_active_power_and_redistribute(6010, north_sea_link_load)  # Set North Sea Link import to 1400 MW
    current_case.set_hvdc_active_power_and_redistribute(5630, nord_link_load)  # Set Nord Link import to 1400 MW
    current_case.disconnect_inactive_generators()
    current_case.run_static_load_flow()
    current_case.save_network_data()

# PREPARATION FOR DYNAMIC ANALYSIS
    current_case.add_event(1.0, 2, 6010, [-north_sea_link_load])  # Step active power to 0 and reactive power to 0
    current_case.add_event(1.0, 2, 5630, [-nord_link_load])
    current_case.prepare_dynamic_simulation(0.005)
    current_case.monitor_channels([3000, 5600, 7000, 8500], [1, 2, 4, 7],
                                  (3000, 3020, 3100, 3249, 5600, 5630, 6010, 7000, 7100), (1, 2, 4),
                                  [[3359, 3359], [5101, 3100]])
    current_case.add_demand_response(dsr_percentage, dsr_time_delay)  # First argument 0.1 = 10% load supplies DSR response

    # HVDC Emergency Power in Norwegian HVDC-links:
    current_case.add_programmable_generation("NORNED_HVDC_EM_POWER")
    current_case.add_programmable_generation("SKAGERAK_1-4_HVDC_EM_POWER")
    #current_case.add_programmable_generation("NORTH_SEA_LINK_HVDC_EM_POWER")  # NSL is outaged
    #current_case.add_programmable_generation("NORDLINK_HVDC_EM_POWER")  # NL is outaged

    # HVDC Emergency Power in Swedish HVDC-links:
    current_case.add_programmable_generation("KONTISKAN_1-2_HVDC_EM_POWER")
    current_case.add_programmable_generation("BALTIC_HVDC_EM_POWER")
    current_case.add_programmable_generation("SWEPOL_HVDC_EM_POWER")
    # current_case.add_programmable_generation("NORDBALT_HVDC_EM_POWER")  # NOT YET IMPLEMENTED

    # HVDC Emergency Power in Finnish HVDC-links:
    # current_case.add_programmable_generation("FENNOSKAN_HVDC_EM_POWER")  # NOT YET IMPLEMENTED
    current_case.add_programmable_generation("ESTLINK_1-2_HVDC_EM_POWER")
    current_case.add_programmable_generation("VYBORG_HVDC_EM_POWER")

# RUN SIMULATION AND POST-PROCESS
    current_case.run_dynamic_simulation()
    current_case.read_results()
    nadir_and_ss = current_case.calculate_coi_frequency()
    current_case.plot_results_and_save()  # Deactivate when running multiple DSR simulations
    reset_cwd_for_next_case = os.path.join(os.getcwd(), "PycharmProject")
    os.chdir(reset_cwd_for_next_case)
    return nadir_and_ss