import psspyObject


def run_case():
    # Outage in Norway with low system inertia and maximum outage of NL and NSL without any kind of SIPS

# CONFIGURE PSSPY VARIABLES AND MODELS
    s = 1.33  # = 1.33 without uvls
    kontiskan_load = -740 * s
    baltic_load = -600 * s
    swepol_load = -600 * s
    current_case = psspyObject.PsspyCase("case3_osf_kontiskan_baltic_swepol_sips")
    current_case.configure_case_options(False, 90.0, 0, 10, True, False, True, True, True)

# STATIC LOAD FLOW ADJUSTMENTS
    current_case.reduce_load_by_x_percentage(0.3)  # 0.1 = 10%
    current_case.add_ufls()
    current_case.add_hvdc_buses()
    current_case.set_hvdc_active_power_and_redistribute(3360, kontiskan_load)  # KontiSkan 740
    current_case.set_hvdc_active_power_and_redistribute(8600, baltic_load)  # Arrie = Baltic 600
    current_case.set_hvdc_active_power_and_redistribute(8700, swepol_load)  # SwePol 600
    current_case.disconnect_inactive_generators_fixed()
    current_case.increase_gen_to_decrease_slack_bus_output(0.1)  # Necessary so slack bus doesn't go crazy
    #current_case.add_uvls()
    current_case.run_static_load_flow()
    current_case.save_network_data()



# PREPARATION FOR DYNAMIC ANALYSIS
    current_case.add_event(1.0, 2, 3360, [-kontiskan_load])  # Step active power to 0 and reactive power to 0
    current_case.add_event(1.0, 2, 8600, [-baltic_load])
    current_case.add_event(1.0, 2, 8700, [-swepol_load])
    current_case.prepare_dynamic_simulation(0.005)
    current_case.monitor_channels([3000, 3300, 6000, 6500, 7000], [1, 2, 4, 7], (3000, 3020, 3100, 3249, 5600, 5630, 6010, 7000, 7100), (1,2,4), [[3359, 3359], [5101, 3100]])

    current_case.add_demand_response(0.1, 1.0)

    # HVDC Emergency Power in Norwegian HVDC-links:
    current_case.add_programmable_generation("NORNED_HVDC_EM_POWER")
    current_case.add_programmable_generation("SKAGERAK_1-4_HVDC_EM_POWER")
    current_case.add_programmable_generation("NORTH_SEA_LINK_HVDC_EM_POWER")  # NSL is outaged
    current_case.add_programmable_generation("NORDLINK_HVDC_EM_POWER")  # NL is outaged

    # HVDC Emergency Power in Swedish HVDC-links:
    #current_case.add_programmable_generation("KONTISKAN_1-2_HVDC_EM_POWER")
    #current_case.add_programmable_generation("BALTIC_HVDC_EM_POWER")
    #current_case.add_programmable_generation("SWEPOL_HVDC_EM_POWER")
    # current_case.add_programmable_generation("NORDBALT_HVDC_EM_POWER")  # NOT YET IMPLEMENTED

    # HVDC Emergency Power in Finnish HVDC-links:
    # current_case.add_programmable_generation("FENNOSKAN_HVDC_EM_POWER")  # NOT YET IMPLEMENTED
    current_case.add_programmable_generation("ESTLINK_1-2_HVDC_EM_POWER")
    current_case.add_programmable_generation("VYBORG_HVDC_EM_POWER")

# RUN SIMULATION AND POST-PROCESS
    current_case.run_dynamic_simulation()
    current_case.read_results()
    current_case.calculate_coi_frequency()
    current_case.plot_results_and_save()
