'''
======================
3D surface (color map)
======================

Demonstrates plotting a 3D surface colored with the coolwarm color map.
The surface is made opaque by using antialiased=False.

Also demonstrates using the LinearLocator and custom formatting for the
z axis tick labels.
'''

from mpl_toolkits.mplot3d import Axes3D
import matplotlib.pyplot as plt
from matplotlib import cm
from matplotlib.ticker import LinearLocator, FormatStrFormatter
import numpy as np

nadir_data_filename = "results_frequency_nadirs_plot_data.txt"  # USER MUST SPECIFY
ss_data_filename = "results_frequency_steady_state_plot_data.txt"  # USER MUST SPECIFY

# Data-files to load
Z_nadir = np.loadtxt(nadir_data_filename)
# Z_nadir = np.delete(Z_nadir, (0), axis=1)
# Z_nadir = np.delete(Z_nadir, (0), axis=1)
Z_ss = np.loadtxt(ss_data_filename)
# Z_ss = np.delete(Z_ss, (0), axis=1)
# Z_ss = np.delete(Z_ss, (0), axis=1)

# Data axes
X = np.loadtxt("frequency_x_axis_time_delay.txt")
Y = np.loadtxt("frequency_y_axis_dsr_percentages.txt")
# Y = Y[2:len(Y)]  # Do not want to plot 0% DSR without primary response; too low nadir
Y = Y*100  # Turn into percentage instead of decimal
X, Y = np.meshgrid(X, Y)


# Figure for plotting frequency nadir
fig = plt.figure()
ax = fig.gca(projection='3d')

# Prepare data
Z_nadir = np.transpose(Z_nadir)

# Plot the surface.
surf = ax.plot_surface(X, Y, Z_nadir, cmap=cm.coolwarm_r, linewidth=0, antialiased=True)

# Customize the z axis.
ax.set_zlim(48.5, 50.0)
ax.zaxis.set_major_locator(LinearLocator(10))
ax.zaxis.set_major_formatter(FormatStrFormatter('%.02f'))
ax.set_xlabel("Time-delay [s]")
ax.set_ylabel("DSR-enabled load [%]")
ax.set_zlabel("Frequency nadir [Hz]")

# Add a color bar which maps values to colors.
fig.colorbar(surf, shrink=0.5, aspect=5)


# Figure for plotting steady-state frequency
fig = plt.figure()
ax = fig.gca(projection='3d')

# Prepare data
Z_ss = np.transpose(Z_ss)

# Plot the surface.
surf = ax.plot_surface(X, Y, Z_ss, cmap=cm.BrBG, linewidth=0, antialiased=True)

# Customize the z axis.
ax.set_zlim(49.5, 50.5)
ax.zaxis.set_major_locator(LinearLocator(10))
ax.zaxis.set_major_formatter(FormatStrFormatter('%.02f'))
ax.set_xlabel("Time-delay [s]")
ax.set_ylabel("DSR-enabled load [%]")
ax.set_zlabel("Steady-state frequency[Hz]")

# Add a color bar which maps values to colors.
fig.colorbar(surf, shrink=0.5, aspect=5)

# Show plots
plt.show()
